#!/usr/bin/env python
#  -*- coding: utf-8 -*-
__author__ = 'jiawenze'

if __name__ == "__main__":
    print("Loading BLTrade.BLStrategy as main programme")
else:
    print("Running BLTrade.BLStrategy as a package")